# Generated by Django 3.2.6 on 2021-08-18 08:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0003_alter_usermodel_email'),
    ]

    operations = [
        migrations.DeleteModel(
            name='UserModel',
        ),
    ]



# import emails
from django.apps import AppConfig


class EmailsConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'emails'

    def ready(self):
        import emails.signals



# Generated by Django 3.2.6 on 2021-09-06 10:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0008_remove_emailreminder_task'),
    ]

    operations = [
        migrations.CreateModel(
            name='Policy',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('user', models.CharField(max_length=20)),
                ('email', models.EmailField(max_length=254)),
                ('policy_name', models.CharField(max_length=30)),
                ('purchase_date', models.DateTimeField()),
                ('end_date', models.DateTimeField()),
                ('amount', models.IntegerField()),
            ],
        ),
    ]



from django.contrib import admin
from .models import *

# Register your models here.
admin.site.register(EmailModel)
admin.site.register(Actions)
admin.site.register(Modules)
admin.site.register(PushReminder)
admin.site.register(Notifications)
admin.site.register(Policies)
admin.site.register(UserEmails)
admin.site.register(EmailReminder)
admin.site.register(List)



# Generated by Django 3.2.6 on 2021-08-30 05:49

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_celery_beat', '0015_edit_solarschedule_events_choices'),
        ('emails', '0006_auto_20210819_0416'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailreminder',
            name='task',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='django_celery_beat.periodictask'),
        ),
    ]



from celery import shared_task
from django.core.mail import send_mail, EmailMessage
from datetime import timedelta, date
import datetime
from .backends import backends, email_from
from django.template.loader import render_to_string, get_template
from django_celery_beat.models import IntervalSchedule, PeriodicTask
from .models import *


# def shared_task(schedule)


# class FilteringPolicyUsers:
#     def __init__(self, model):
#         self.model = model
#
#     def data_filter(self, n_days, types):
#         dates = datetime.date.today() + timedelta(n_days)
#         queryset = self.model.objects.filter(end_date=dates)
#         count = queryset.count()
#         email_reminder = EmailReminderSelection(EmailReminder)
#         alert = email_reminder.alert_notification(types)
#         if alert:
#             if alert.status:
#                 for i in range(count):
#                     if alert.occurrence:
#                         send_mail_task(alert.subject, alert.body, alert.signature, queryset[i].user, queryset[i].email)
#                     else:
#                         pass
#
#             else:
#                 return None
#         else:
#             pass
#
#
# class EmailReminderSelection:
#     def __init__(self, model):
#         self.model = model
#
#     def alert_notification(self, types):
#         mail = self.model.objects.get(email_notification_type=types)
#         return mail
#
#
# @shared_task
# def filtering():
#     users = FilteringPolicyUsers(Policies)
#     users.data_filter(5, 6)
#     users.data_filter(2, 7)
#
#
@shared_task
def send_mail_task(user, emails, subject, body, signature):
    template = get_template('email.html')
    content = template.render({'user': user, 'body': body, 'signature': signature})
    email = EmailMessage(subject=subject, body=content, from_email=email_from, to=[emails],
                         connection=backends)
    email.content_subtype = "html"
    email.send()
    print("send_mail_task")
    print(user, emails, subject, body, signature,"tasks")





# Generated by Django 3.2.6 on 2021-08-18 07:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='UserModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=20, unique=True)),
            ],
        ),
    ]



# from rest_framework import viewsets
# from rest_framework.generics import get_object_or_404
# from .serializers import *
# from rest_framework import status
# from django.apps import apps
# from rest_framework.response import Response
# from .tasks import *


# # Create your views here.

# class EmailSettingAPIView(viewsets.ModelViewSet):
#     serializer_class = EmailSerializers
#     queryset = EmailModel.objects.all()

#     def create(self, request, *args, **kwargs):
#         serializer = self.get_serializer(data=request.data)
#         serializer.is_valid(raise_exception=True)
#         self.perform_create(serializer)

#         headers = self.get_success_headers(serializer.data)
#         return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)


# class EmailReminderView(viewsets.ModelViewSet):
#     serializer_class = EmailReminderSerializer
#     queryset = EmailReminder.objects.all()

#     def create(self, request, *args, **kwargs):
#         serializer = self.get_serializer(data=request.data)
#         serializer.is_valid(raise_exception=True)
#         serializer.save()
#         data = serializer.data
#         if not List.objects.filter(list=data.get('modules')).exists():
#             List.objects.create(list=data.get('modules'))
#             return Response('success')
#         return Response('already exist')

#     def destroy(self, request, pk=None, *args, **kwargs):
#         queryset = EmailReminder.objects.all()
#         reminder = get_object_or_404(queryset, pk=pk)
#         reminder.is_deleted = True
#         reminder.save()
#         serializer = EmailReminderSerializer(reminder)
#         return Response(serializer.data)


# class PushReminderView(viewsets.ModelViewSet):
#     serializer_class = PushReminderSerializer
#     queryset = PushReminder.objects.all()

#     def destroy(self, request, pk=None, *args, **kwargs):
#         queryset = PushReminder.objects.all()
#         reminder = get_object_or_404(queryset, pk=pk)
#         reminder.is_deleted = True
#         reminder.save()
#         serializer = PushReminderSerializer(reminder)
#         return Response(serializer.data)


# class PolicyView(viewsets.ModelViewSet):
#     serializer_class = PolicySerializer
#     queryset = Policies.objects.all()


# class ModuleView(viewsets.ModelViewSet):
#     serializer_class = ModuleSerializer
#     queryset = Modules.objects.all()

#     def create(self, request, *args, **kwargs):
#         app_models = [model.__name__ for model in apps.get_models()]
#         print(app_models)
#         count = len(app_models)
#         print(count)
#         for i in range(count):
#             print(i)
#             module = Modules.objects.create(modules=app_models[i])
#             module.save()
#         # return "module"


from rest_framework import viewsets
from rest_framework.generics import get_object_or_404
from .serializers import *
from rest_framework import status
from django.apps import apps
from rest_framework.response import Response
from .tasks import *


# Create your views here.

class EmailSettingAPIView(viewsets.ModelViewSet):
    serializer_class = EmailSerializers
    queryset = EmailModel.objects.all()

    def create(self, request, *args, **kwargs):
        serializer = self.get_serializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        self.perform_create(serializer)

        headers = self.get_success_headers(serializer.data)
        return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)


class EmailReminderView(viewsets.ModelViewSet):
    serializer_class = EmailReminderSerializer
    queryset = EmailReminder.objects.all()

    def create(self, request, *args, **kwargs):
        serializer = self.get_serializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        data = serializer.data
        if not List.objects.filter(list=data.get('modules')).exists():
            List.objects.create(list=data.get('modules'))
            return Response('success')
        return Response('already exist')

    def destroy(self, request, pk=None, *args, **kwargs):
        queryset = EmailReminder.objects.all()
        reminder = get_object_or_404(queryset, pk=pk)
        reminder.is_deleted = True
        reminder.save()
        serializer = EmailReminderSerializer(reminder)
        return Response(serializer.data)


class PushReminderView(viewsets.ModelViewSet):
    serializer_class = PushReminderSerializer
    queryset = PushReminder.objects.all()

    def destroy(self, request, pk=None, *args, **kwargs):
        queryset = PushReminder.objects.all()
        reminder = get_object_or_404(queryset, pk=pk)
        reminder.is_deleted = True
        reminder.save()
        serializer = PushReminderSerializer(reminder)
        return Response(serializer.data)


class PolicyView(viewsets.ModelViewSet):
    serializer_class = PolicySerializer
    queryset = Policies.objects.all()


class ModuleView(viewsets.ModelViewSet):
    serializer_class = ModuleSerializer
    queryset = Modules.objects.all()

    def create(self, request, *args, **kwargs):
        app_models = apps.all_models['emails']
        app_models_list = list(app_models.values())
        model_list = [app_models_list[i].__name__ for i in range(len(app_models_list))]
        for i in range(len(model_list)):
            module = Modules.objects.create(modules=model_list[i])
            module.save()
        return Response("success")


class User(viewsets.ModelViewSet):
    serializer_class = UserSerializer
    queryset = UserEmails.objects.all()



# from django.db.models.signals import post_save
# from django.dispatch import receiver
# from .tasks import *
# from .models import *
# from django.apps import apps


# @receiver(post_save)
# def send_mail_tasks(sender, instance=None, created=False, **kwargs):
#     app_models = append()
#     if sender.__name__ in app_models:
#         if created:
#             mail = EmailReminder.objects.filter(actions='Created', modules=sender.__name__)
#             if mail.status:
#                 send_mail_task(instance.user, instance.email, mail.subject, mail.body, mail.signature)
#                 print("success")
#             else:
#                 print("status error")
#         else:
#             print("created error")


# post_save.connect(send_mail_tasks)


# def append():
#     list_data = List.objects.all()
#     list_pass = []
#     counts = list_data.count()
#     for i in range(counts):
#         list_pass.append(list_data[i].list)
#     return list_pass


from django.db.models.signals import post_save
from django.dispatch import receiver
from .tasks import *
from .models import *
from django.apps import apps


@receiver(post_save)
def send_mail_tasks(sender, instance=None, created=False, **kwargs):
    app_models = append()
    if sender.__name__ in app_models:
        if created:
            mail = EmailReminder.objects.get(actions__signal_action='Created', modules__modules=sender.__name__)
            if mail.status:
                send_mail_task.apply_async(args=(instance.user, instance.email, mail.subject, mail.body, mail.signature),
                                           eta=mail.date_time)


post_save.connect(send_mail_tasks)


def append():
    list_data = List.objects.all()
    list_pass = []
    counts = list_data.count()
    for i in range(counts):
        list_pass.append(list_data[i].list)
    return list_pass



# Generated by Django 3.2.6 on 2021-08-19 04:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0005_emailreminder_notifications_pushreminder'),
    ]

    operations = [
        migrations.AlterField(
            model_name='emailreminder',
            name='occurrence',
            field=models.BooleanField(choices=[(True, 'single'), (False, 'recurring')], help_text='True for single'),
        ),
        migrations.AlterField(
            model_name='emailreminder',
            name='schedule',
            field=models.BooleanField(choices=[(True, 'before'), (False, 'after')]),
        ),
        migrations.AlterField(
            model_name='pushreminder',
            name='occurrence',
            field=models.BooleanField(choices=[(True, 'single'), (False, 'recurring')], help_text='True for single'),
        ),
        migrations.AlterField(
            model_name='pushreminder',
            name='schedule',
            field=models.BooleanField(choices=[(True, 'before'), (False, 'after')]),
        ),
    ]



"""Email URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from rest_framework.routers import DefaultRouter
from .views import *
from django.urls import path, include
from django.conf import settings
from django.conf.urls.static import static

router = DefaultRouter()
router.register('register', EmailSettingAPIView, basename='')
router.register('email_reminder', EmailReminderView, basename='email_reminder')
router.register('push_reminder', PushReminderView, basename='push_reminder')
router.register('policy', PolicyView, basename='policy')
router.register('modules', ModuleView, basename='modules')
router.register('user',User,basename = "user")
urlpatterns = [
    path('project-mailer', include(router.urls)),

]
if settings.DEBUG:
    urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)



from django.core.mail.backends.smtp import EmailBackend
from .models import EmailModel

email_data = EmailModel.objects.get(id=4)
backends = EmailBackend(host=email_data.email_host, port=email_data.email_port,
                        username=email_data.email_host_user, password=email_data.email_host_password,
                        use_tls=email_data.email_use_tls
                        )


def email_from(request):
    from_email = email_data.email_host_user
    request.session['from_email'] = from_email
    return from_email



import os
from celery.schedules import crontab
from celery import Celery

os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'Email.settings')

app = Celery('emails')

app.config_from_object('django.conf:settings', namespace='CELERY')

app.autodiscover_tasks()
app.conf.beat_schedule = {
    # Executes every Monday morning at 7:30 a.m.
    'add-every-monday-morning': {
        'task': 'emails.tasks.filtering',
        'schedule': crontab(minute=57, hour=11),
    },
    'add-every-30-seconds': {
        'task': 'emails.tasks.send_mail_task',
        'schedule': 30.0,
        'options': {
            # ensure we don't accumulate a huge backlog of these if the workers are down
            'expires': 300,
        },
    },
}


# app.conf.beat_schedule = {
#     'add-every-30-seconds': {
#         'task': 'emails.tasks.send_mail_rec',
#         'schedule': 10.0,
#     },
# }
@app.task(bind=True)
def debug_task(self):
    print(f'Request: {self.request!r}')



from django.db import models
from django.db import models, signals


# Create your models here.


class EmailModel(models.Model):
    creator_name = models.CharField(max_length=20)
    email_host = models.CharField(max_length=30)
    email_use_tls = models.BooleanField(help_text="True for Gmail")
    email_use_ssl = models.BooleanField(help_text="False for Gmail")
    email_port = models.IntegerField()
    email_host_user = models.EmailField()
    email_host_password = models.CharField(max_length=50)
    data_created = models.DateField(auto_now_add=True)
    last_modified = models.DateField(auto_now=True)

    def save(self, *args, **kwargs):
        if EmailModel.objects.exists():
            pass
        else:
            self.pk = 1
        super(EmailModel, self).save(*args, **kwargs)

    def __str__(self):
        return f'{self.pk} {self.email_host_user}'


class Notifications(models.Model):
    notification_type = models.CharField(max_length=30)

    def __str__(self):
        return self.notification_type


class Actions(models.Model):
    signal_action = models.CharField(max_length=25)

    def __str__(self):
        return self.signal_action


class List(models.Model):
    list = models.CharField(max_length=20)


class Modules(models.Model):
    modules = models.CharField(max_length=20)

    def __str__(self):
        return self.modules


class Policies(models.Model):
    user = models.CharField(max_length=20)
    email = models.EmailField()
    policy_name = models.CharField(max_length=30)
    purchase_date = models.DateField()
    end_date = models.DateField()
    amount = models.IntegerField()

    def __str__(self):
        return self.user


class UserEmails(models.Model):
    user = models.CharField(max_length=20)
    email = models.EmailField()
    subject = models.CharField(max_length=20)
    body = models.TextField(max_length=500)
    signature = models.TextField(max_length=100)


class EmailReminder(models.Model):
    occurrence_type = ((True, 'single'), (False, 'recurring'))
    schedule_type = ((True, 'before'), (False, 'after'))
    email_notification_type = models.ForeignKey(Notifications, on_delete=models.CASCADE)
    subject = models.CharField(max_length=20)
    body = models.TextField(max_length=500)
    signature = models.TextField(max_length=100)
    occurrence = models.BooleanField(choices=occurrence_type, help_text="True for single")
    schedule = models.BooleanField(choices=schedule_type)
    status = models.BooleanField(default=True)
    schedule_days = models.IntegerField(blank=True, null=True)
    schedule_hours = models.IntegerField(blank=True, null=True)
    schedule_minutes = models.IntegerField(blank=True, null=True)
    interval_days = models.IntegerField(blank=True, null=True)
    interval_hours = models.IntegerField(blank=True, null=True)
    interval_minutes = models.IntegerField(blank=True, null=True)
    date_time = models.DateTimeField(null=True)
    modules = models.ForeignKey(Modules, on_delete=models.PROTECT)
    actions = models.ForeignKey(Actions, on_delete=models.PROTECT)
    is_deleted = models.BooleanField(default=False)
    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)

    def __str__(self):
        return str(self.email_notification_type)


class PushReminder(models.Model):
    occurrence_type = ((True, 'single'), (False, 'recurring'))
    schedule_type = ((True, 'before'), (False, 'after'))
    title = models.CharField(max_length=20)
    message = models.TextField(max_length=100)
    image = models.ImageField(upload_to='reminder')
    url = models.URLField()
    occurrence = models.BooleanField(choices=occurrence_type, help_text="True for single")
    schedule = models.BooleanField(choices=schedule_type)
    status = models.BooleanField(default=True)
    interval_period = models.DateTimeField()
    is_deleted = models.BooleanField(default=False)
    created_at = models.DateTimeField(auto_now_add=True)
    updated_at = models.DateTimeField(auto_now=True)

    def __str__(self):
        return self.title



from rest_framework import serializers
from rest_framework.exceptions import ValidationError

from .models import *
from rest_framework.validators import UniqueTogetherValidator


class EmailSerializers(serializers.ModelSerializer):
    creator_name = serializers.CharField(max_length=20)
    email_host = serializers.RegexField(regex=r'^(([a-z]+)\.){2}([a-z]+)$', required=True,
                                        error_messages={'required': 'Please enter valid host name',
                                                        'invalid': 'example (Smtp.gmail.com)'})
    email_host_password = serializers.CharField(max_length=50, write_only=True,
                                                required=True,
                                                style={'input_type': 'password', 'placeholder': 'Password'}
                                                )
    email_use_tls = serializers.BooleanField(help_text="True for Gmail")
    email_use_ssl = serializers.BooleanField(help_text="False for Gmail")

    # def validate(self, validated_data):
    #     if EmailModel.objects.exists():
    #         raise ValidationError("Multiple Objects is not allowed this model..")
    #     return super().validate(validated_data)
    #
    # def create(self, validated_data):
    #     validated_data['id'] = 1
    #     return super(EmailSerializers, self).create(validated_data)

    class Meta:
        model = EmailModel
        fields = '__all__'
        validators = [
            UniqueTogetherValidator(
                queryset=EmailModel.objects.all(),
                fields=['email_host_user']
            )
        ]


class EmailReminderSerializer(serializers.ModelSerializer):
    class Meta:
        model = EmailReminder
        fields = '__all__'

    def to_representation(self, instance):
        rep = super(EmailReminderSerializer, self).to_representation(instance)
        rep['modules'] = instance.modules.modules
        rep['actions'] = instance.actions.signal_action
        return rep


class PushReminderSerializer(serializers.ModelSerializer):
    class Meta:
        model = PushReminder
        fields = '__all__'


class PolicySerializer(serializers.ModelSerializer):
    class Meta:
        model = Policies
        fields = '__all__'


class ModuleSerializer(serializers.ModelSerializer):
    class Meta:
        model = Modules
        fields = '__all__'

class UserSerializer(serializers.ModelSerializer):
    class Meta:
        model = UserEmails
        fields ='__all__'



# Generated by Django 3.2.6 on 2021-09-10 09:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0016_delete_emailreminder'),
    ]

    operations = [
        migrations.CreateModel(
            name='Modules',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('modules', models.CharField(max_length=20)),
            ],
        ),
        migrations.CreateModel(
            name='EmailReminder',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(max_length=20)),
                ('body', models.TextField(max_length=500)),
                ('signature', models.TextField(max_length=100)),
                ('occurrence', models.BooleanField(choices=[(True, 'single'), (False, 'recurring')], help_text='True for single')),
                ('schedule', models.BooleanField(choices=[(True, 'before'), (False, 'after')])),
                ('status', models.BooleanField(default=True)),
                ('schedule_days', models.IntegerField(blank=True, null=True)),
                ('schedule_hours', models.IntegerField(blank=True, null=True)),
                ('schedule_minutes', models.IntegerField(blank=True, null=True)),
                ('interval_days', models.IntegerField(blank=True, null=True)),
                ('interval_hours', models.IntegerField(blank=True, null=True)),
                ('interval_minutes', models.IntegerField(blank=True, null=True)),
                ('is_deleted', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('actions', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='emails.actions')),
                ('email_notification_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='emails.notifications')),
                ('modules', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='emails.modules')),
            ],
        ),
    ]



# Generated by Django 3.2.6 on 2021-09-06 06:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0007_emailreminder_task'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='emailreminder',
            name='task',
        ),
    ]



# Generated by Django 3.2.5 on 2021-09-14 05:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0019_list'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailreminder',
            name='date_time',
            field=models.DateTimeField(null=True),
        ),
    ]



# Generated by Django 3.2.6 on 2021-09-10 12:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0018_delete_notify'),
    ]

    operations = [
        migrations.CreateModel(
            name='List',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('list', models.CharField(max_length=20)),
            ],
        ),
    ]



# Generated by Django 3.2.6 on 2021-08-17 13:47

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='EmailModel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('creator_name', models.CharField(max_length=20)),
                ('email_host', models.CharField(max_length=30)),
                ('email_use_tls', models.BooleanField(help_text='True for Gmail')),
                ('email_use_ssl', models.BooleanField(help_text='False for Gmail')),
                ('email_port', models.IntegerField()),
                ('email_host_user', models.EmailField(max_length=254)),
                ('email_host_password', models.CharField(max_length=50)),
                ('data_created', models.DateField(auto_now_add=True)),
                ('last_modified', models.DateField(auto_now=True)),
            ],
        ),
    ]



# Generated by Django 3.2.6 on 2021-08-18 12:47

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0004_delete_usermodel'),
    ]

    operations = [
        migrations.CreateModel(
            name='Notifications',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('notification_type', models.CharField(max_length=30)),
            ],
        ),
        migrations.CreateModel(
            name='PushReminder',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=20)),
                ('message', models.TextField(max_length=100)),
                ('image', models.ImageField(upload_to='reminder')),
                ('url', models.URLField()),
                ('occurrence', models.BooleanField(choices=[('Single', True), ('Recurring', False)], help_text='True for single')),
                ('schedule', models.BooleanField(choices=[('Before', True), ('After', False)])),
                ('status', models.BooleanField(default=True)),
                ('interval_period', models.DateTimeField()),
                ('is_deleted', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
            ],
        ),
        migrations.CreateModel(
            name='EmailReminder',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('subject', models.CharField(max_length=20)),
                ('body', models.TextField(max_length=500)),
                ('signature', models.TextField(max_length=100)),
                ('occurrence', models.BooleanField(choices=[('Single', True), ('Recurring', False)], help_text='True for single')),
                ('schedule', models.BooleanField(choices=[('Before', True), ('After', False)])),
                ('status', models.BooleanField(default=True)),
                ('interval_period', models.DateTimeField()),
                ('is_deleted', models.BooleanField(default=False)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('email_notification_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='emails.notifications')),
            ],
        ),
    ]



# Generated by Django 3.2.6 on 2021-08-18 07:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('emails', '0002_usermodel'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usermodel',
            name='email',
            field=models.EmailField(max_length=254, unique=True),
        ),
    ]
